@@ -1,7 +1,7 @@
 # Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
 #
 # This module is part of GitDB and is released under
-# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
+# the New BSD License: https://opensource.org/license/bsd-3-clause/
 """Module containing a database to deal with packs"""
 from gitdb.db.base import (
     FileDBBase,
@@ -39,7 +39,7 @@ class PackedDB(FileDBBase, ObjectDBR, CachingDB, LazyMixin):
     _sort_interval = 500
 
     def __init__(self, root_path):
-        super(PackedDB, self).__init__(root_path)
+        super().__init__(root_path)
         # list of lists with three items:
         # * hits - number of times the pack was hit with a request
         # * entity - Pack entity instance
@@ -131,7 +131,7 @@ class PackedDB(FileDBBase, ObjectDBR, CachingDB, LazyMixin):
 
     def update_cache(self, force=False):
         """
-        Update our cache with the acutally existing packs on disk. Add new ones,
+        Update our cache with the actually existing packs on disk. Add new ones,
         and remove deleted ones. We keep the unchanged ones
 
         :param force: If True, the cache will be updated even though the directory
